# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.6.0~d757fc2',
    built_at='2024-05-07 07:12:48Z',
    sha='d757fc2d04540ca906d699f9665f16aeea3d7b81',
    branch='HEAD',
    tag='v4.6.0',
)
